@@ -261,6 +261,33 @@ class PedidoVenda(models.Model):
     def __unicode__(self):
         return unicode(self.id)
 
+    def criar_endereco(self, tipo, endereco):
+        """Cria um endereço para o pedido baseado em um endereço do cliente."""
+        # O tipo de endereço só pode ser pagamento ou entrega e o objeto deve
+        # ser uma instância do endereço do cliente.
+        assert tipo in ['entrega', 'pagamento']
+        assert isinstance(endereco, ClienteEndereco)
+
+        campos = ['tipo', 'cpf', 'rg', 'cnpj', 'razao_social', 'ie', 'nome',
+                  'endereco', 'numero', 'complemento', 'referencia', 'bairro',
+                  'cidade', 'estado', 'cep', 'pais']
+        valores = {}
+        for campo in campos:
+            valores[campo] = getattr(endereco, campo)
+            if campo in ['tipo', 'cpf', 'rg', 'cnpj', 'razao_social', 'ie']:
+                if not getattr(endereco, campo):
+                    valores[campo] = getattr(endereco.cliente.endereco(), campo)
+
+        try:
+            novo_endereco = PedidoVendaEndereco.objects.filter(
+                conta=self.conta, **valores)[0]
+        except IndexError:
+            novo_endereco = PedidoVendaEndereco(conta=self.conta)
+            for campo, valor in valores.items():
+                setattr(novo_endereco, campo, valor)
+            novo_endereco.save()
+        return novo_endereco
+
     def _set_endereco_entrega(self, endereco):
         """Ao definir um endereço de entrega é possível definir como um
         endereço do cliente ou como um endereço do pedido.
@@ -277,6 +304,22 @@ class PedidoVenda(models.Model):
 
     endereco_entrega = property(_get_endereco_entrega, _set_endereco_entrega)
 
+    def _set_endereco_pagamento(self, endereco):
+        """Ao definir um endereço de pagamento é possível definir como um
+        endereço do cliente ou como um endereço do pedido.
+        """
+        if isinstance(endereco, PedidoVendaEndereco):
+            self._endereco_pagamento = endereco
+        elif isinstance(endereco, ClienteEndereco):
+            self._endereco_pagamento = self.criar_endereco('pagamento', endereco)
+        else:
+            raise TypeError(u'O endereço deve ser do tipo Endereco ou PedidoVendaEndereco. %s foi enviado.' % type(endereco))
+
+    def _get_endereco_pagamento(self):
+        return self._endereco_pagamento
+
+    endereco_pagamento = property(_get_endereco_pagamento, _set_endereco_pagamento)
+
     @property
     def prazo_entrega(self):
         prazo_envio = self.prazo_envio or 0
